@@ -33,13 +33,13 @@ public:
     {
         q->setWindowTitle(i18nc("@title:window", "Insert HTML"));
         auto lay = new QVBoxLayout(q);
-        auto label = new QLabel(i18n("Insert HTML tags and texts:"));
+        auto label = new QLabel(i18nc("@label:textbox", "Insert HTML tags and texts:"));
         lay->addWidget(label);
         editor = new InsertHtmlEditor;
         editor->setSpellCheckingSupport(false);
         auto editorWidget = new TextCustomEditor::PlainTextEditorWidget(editor);
         lay->addWidget(editorWidget);
-        label = new QLabel(i18n("Example: <i> Hello word </i>"));
+        label = new QLabel(i18nc("@label:textbox", "Example: <i> Hello word </i>"));
         QFont font = label->font();
         font.setBold(true);
         label->setFont(font);
