@@ -80,7 +80,7 @@ public:
         lay->addWidget(sep);
 
         hbox = new QHBoxLayout;
-        useBackgroundColor = new QCheckBox(i18n("Background Color:"));
+        useBackgroundColor = new QCheckBox(i18nc("@option:check", "Background Color:"));
 
         hbox->addWidget(useBackgroundColor);
         backgroundColor = new KColorButton;
